@@ -39,15 +39,6 @@ function defineCommonExtensionSymbols(apiPrivate)
         Severe: "severe"
     };
 
-    if (!apiPrivate.console)
-        apiPrivate.console = {};
-    apiPrivate.console.Severity = {
-        Debug: "debug",
-        Log: "log",
-        Warning: "warning",
-        Error: "error"
-    };
-
     if (!apiPrivate.panels)
         apiPrivate.panels = {};
     apiPrivate.panels.SearchAction = {
@@ -60,7 +51,6 @@ function defineCommonExtensionSymbols(apiPrivate)
     apiPrivate.Events = {
         AuditStarted: "audit-started-",
         ButtonClicked: "button-clicked-",
-        ConsoleMessageAdded: "console-message-added",
         PanelObjectSelected: "panel-objectSelected-",
         NetworkRequestFinished: "network-request-finished",
         OpenResource: "open-resource",
@@ -74,15 +64,13 @@ function defineCommonExtensionSymbols(apiPrivate)
     apiPrivate.Commands = {
         AddAuditCategory: "addAuditCategory",
         AddAuditResult: "addAuditResult",
-        AddConsoleMessage: "addConsoleMessage",
         AddRequestHeaders: "addRequestHeaders",
         ApplyStyleSheet: "applyStyleSheet",
         CreatePanel: "createPanel",
         CreateSidebarPane: "createSidebarPane",
-        CreateStatusBarButton: "createStatusBarButton",
+        CreateToolbarButton: "createToolbarButton",
         EvaluateOnInspectedPage: "evaluateOnInspectedPage",
         ForwardKeyboardEvent: "_forwardKeyboardEvent",
-        GetConsoleMessages: "getConsoleMessages",
         GetHAR: "getHAR",
         GetPageResources: "getPageResources",
         GetRequestContent: "getRequestContent",
@@ -190,32 +178,6 @@ function InspectorExtensionAPI()
     this.panels = new Panels();
     this.network = new Network();
     defineDeprecatedProperty(this, "webInspector", "resources", "network");
-    this.console = new ConsoleAPI();
-}
-
-/**
- * @constructor
- */
-function ConsoleAPI()
-{
-    this.onMessageAdded = new EventSink(events.ConsoleMessageAdded);
-}
-
-ConsoleAPI.prototype = {
-    getMessages: function(callback)
-    {
-        extensionServer.sendRequest({ command: commands.GetConsoleMessages }, callback);
-    },
-
-    addMessage: function(severity, text, url, line)
-    {
-        extensionServer.sendRequest({ command: commands.AddConsoleMessage, severity: severity, text: text, url: url, line: line });
-    },
-
-    get Severity()
-    {
-        return apiPrivate.console.Severity;
-    }
 }
 
 /**
@@ -410,7 +372,7 @@ function declareInterfaceClass(implConstructor)
         var impl = { __proto__: implConstructor.prototype };
         implConstructor.apply(impl, arguments);
         populateInterfaceClass(this, impl);
-    }
+    };
 }
 
 function defineDeprecatedProperty(object, className, oldName, newName)
@@ -487,7 +449,7 @@ ExtensionPanelImpl.prototype = {
     {
         var id = "button-" + extensionServer.nextObjectId();
         var request = {
-            command: commands.CreateStatusBarButton,
+            command: commands.CreateToolbarButton,
             panel: this._id,
             id: id,
             icon: iconPath,
@@ -640,7 +602,7 @@ AuditResultImpl.prototype = {
     {
         // shorthand for specifying details directly in addResult().
         if (details && !(details instanceof AuditResultNode))
-            details = new AuditResultNode(details instanceof Array ? details : [details]);
+            details = new AuditResultNode(Array.isArray(details) ? details : [details]);
 
         var request = {
             command: commands.AddAuditResult,
@@ -753,9 +715,9 @@ InspectedWindow.prototype = {
     reload: function(optionsOrUserAgent)
     {
         var options = null;
-        if (typeof optionsOrUserAgent === "object")
+        if (typeof optionsOrUserAgent === "object") {
             options = optionsOrUserAgent;
-        else if (typeof optionsOrUserAgent === "string") {
+        } else if (typeof optionsOrUserAgent === "string") {
             options = { userAgent: optionsOrUserAgent };
             console.warn("Passing userAgent as string parameter to inspectedWindow.reload() is deprecated. " +
                          "Use inspectedWindow.reload({ userAgent: value}) instead.");
@@ -805,7 +767,7 @@ InspectedWindow.prototype = {
  */
 function ResourceImpl(resourceData)
 {
-    this._url = resourceData.url
+    this._url = resourceData.url;
     this._type = resourceData.type;
 }
 
@@ -928,7 +890,7 @@ ExtensionServerClient.prototype = {
      */
     nextObjectId: function()
     {
-        return injectedScriptId + "_" + ++this._lastObjectId;
+        return injectedScriptId.toString() + "_" + ++this._lastObjectId;
     },
 
     _registerCallback: function(callback)
@@ -992,7 +954,7 @@ function platformExtensionAPI(coreAPI)
     {
         return tabId;
     }
-    chrome = window.chrome || {};
+    var chrome = window.chrome || {};
     // Override chrome.devtools as a workaround for a error-throwing getter being exposed
     // in extension pages loaded into a non-extension process (only happens for remote client
     // extensions)
@@ -1024,26 +986,28 @@ function platformExtensionAPI(coreAPI)
 
 /**
  * @param {!ExtensionDescriptor} extensionInfo
+ * @param {string} inspectedTabId
  * @return {string}
  */
-function buildPlatformExtensionAPI(extensionInfo)
+function buildPlatformExtensionAPI(extensionInfo, inspectedTabId)
 {
     return "var extensionInfo = " + JSON.stringify(extensionInfo) + ";" +
-       "var tabId = " + WebInspector._inspectedTabId + ";" +
+       "var tabId = " + inspectedTabId + ";" +
        platformExtensionAPI.toString();
 }
 
 /**
  * @param {!ExtensionDescriptor} extensionInfo
+ * @param {string} inspectedTabId
  * @return {string}
  */
-function buildExtensionAPIInjectedScript(extensionInfo)
+function buildExtensionAPIInjectedScript(extensionInfo, inspectedTabId)
 {
     return "(function(injectedScriptId){ " +
         "var extensionServer;" +
         defineCommonExtensionSymbols.toString() + ";" +
         injectedExtensionAPI.toString() + ";" +
-        buildPlatformExtensionAPI(extensionInfo) + ";" +
+        buildPlatformExtensionAPI(extensionInfo, inspectedTabId) + ";" +
         "platformExtensionAPI(injectedExtensionAPI(injectedScriptId));" +
         "return {};" +
         "})";
